# -*- coding: UTF-8 -*-

__title__ = 'fastposter'
__description__ = 'fastposter make poster development easy.'
__url__ = 'https://cloud.fastposter.net/doc/'
__version__ = '1.2.0'
__author__ = 'Alex'
__author_email__ = 'service@fastposter.net'
__license__ = 'MIT'
__copyright__ = 'Copyright 2023 fastposter.net'

